.. _user-guide:

User Guide
==========

.. toctree::
   :caption: Introduction
   :hidden:

   about
   installation
   running_a_simulation

.. toctree::
   :caption: Simulations
   :hidden:

   Soccer Simulation <soccer_simulation>

.. toctree::
   :caption: Simulation Server
   :hidden:

   simulation_server
   agent_protocol
   monitor_protocol
   robots/index

.. toctree::
   :caption: Machine Learning
   :hidden:

   managed_simulation

Some info for the user...
